#//-----------------------------------------------
#//TUSB-S01PT用サンプルプログラム (Continuous)
#//Python 用モジュール
#//
#//2024_07_18　株式会社タートル工業
#//Copyright (C) 2024 Turtle Industry Co.,Ltd.
#//-----------------------------------------------

import TUSBSPT
from functools import partial
from SpFuncs import *
import sys

class Tusbs01pt_Device:
    """TUSB-S01PT デバイス操作クラス フォーム"""
    DevId = None                    # デバイスID

    def __init__(self,DevId):
        """イニシャライザ
        
        Arguments:
        DevId           ----    Device Id 0~15
        """
        self.formgen()
        ret = TUSBSPT.Tusbs01pt_Device_Open(DevId)                  # デバイスオープン
        if ret == 0:    # 正常オープン
            self.DevId = DevId                                      # デバイスIDをクラスメンバ変数に保持する
            self.form.protocol("WM_DELETE_WINDOW",self.DevClose)
        else:
            ShowInfo(TUSBSPT.GetErrMessage(ret))                    # 失敗エラーメッセージ表示
            self.form.destroy()                                     # フォームを閉じる 

    def DevClose(self):
        """デバイスを閉じる時の処理"""
        if self.DevId != None:
            TUSBSPT.Tusbs01pt_Device_Close(self.DevId)              # デバイスクローズ
            self.form.destroy()                                     # フォームを閉じる
            self.DevId = None

    # ボタン等ウィジットの操作イベントハンドラ ----------------------
    def BtnStart_on(self):
        """取り込みボタンハンドラ"""
        ret = TUSBSPT.Tusbs01pt_Start_Sample(self.DevId, 1)     # 取込開始(取込周期10ms)
        if ret != 0:
            ShowInfo(TUSBSPT.GetErrMessage(ret))
            return
        self.LstbxTemp.delete(0,tk.END)    # 過去のリストボックスログを消す
        TotalCnt = 0
        # 温度データを10個取り込む
        while TotalCnt < 10:
            ret = TUSBSPT.Tusbs01pt_Get_Datas(self.DevId,10,self.CmbbConn.current(),1)    # 取得済み温度データを要求する
            if ret[0] != 0: return
            for dat in ret[1]:
                self.LstbxTemp.insert(tk.END,format(dat,"5.1f")+" ℃")
                TotalCnt += 1
                if TotalCnt >= 10:
                    break

    # フォームとウィジェットを生成する処理---------------------------
    def formgen(self):
        self.form = tk.Tk()
        form = self.form
        form.geometry('336x327')
        form.title('TUSB-S01PT Sample Program (continuous)')

        self.ConnDict ={
            "2線式":0,
            "3線式":1,
            "4線式":2,
        }
        self.LstbxTemp = GenListBox(form,0.6,0.7,0.2,0.05)
        self.BtnStart = GetButton(form,"取込",self.BtnStart_on,0.2,0.5,0.85)
        self.CmbbConn = GetComboBox(form,list(self.ConnDict.keys()),0.2,0.75,0.85)

# 実行部 ---------------------------------
if __name__=="__main__":
    DevId = 0
    if( len(sys.argv) >= 2 ):
        if sys.argv[1].isdigit():
            DevId = int(sys.argv[1])    # コマンドライン引数でID設定
    tmp = Tusbs01pt_Device(DevId=DevId)
    tmp.form.mainloop()
