#//-----------------------------------------------
#//TUSB-S01PT用サンプルプログラム (Single)
#//Python 用モジュール
#//
#//2024_07_18　株式会社タートル工業
#//Copyright (C) 2024 Turtle Industry Co.,Ltd.
#//-----------------------------------------------

import TUSBSPT
from functools import partial
from SpFuncs import *
import sys

class Tusbs01pt_Device:
    """TUSB-S01PT デバイス操作クラス フォーム"""
    DevId = None                    # デバイスID
    smpl_t = None                   # サンプリングタイマー
    SMPL_BTN_START = "開始"         # 計測開始停止ボタン開始表示文字列
    SMPL_BTN_STOP = "停止"          # 計測開始停止ボタン停止表示文字列

    def __init__(self,DevId):
        """イニシャライザ
        
        Arguments:
        DevId           ----    Device Id 0~15
        """
        self.formgen()
        ret = TUSBSPT.Tusbs01pt_Device_Open(DevId)                  # デバイスオープン
        if ret == 0:    # 正常オープン
            self.DevId = DevId                                      # デバイスIDをクラスメンバ変数に保持する
            self.form.protocol("WM_DELETE_WINDOW",self.DevClose)
            self.smpl_t = intTT(0.1,self.SampleT)                   # モニタータイマー作成、コールバック関数登録
        else:
            ShowInfo(TUSBSPT.GetErrMessage(ret))                    # 失敗エラーメッセージ表示
            self.form.destroy()                                     # フォームを閉じる 
    
    def DevClose(self):
        """デバイスを閉じる時の処理"""
        if self.DevId != None:
            if self.smpl_t != None:
                self.smpl_t.Stop()                                  # タイマー終了
            TUSBSPT.Tusbs01pt_Device_Close(self.DevId)              # デバイスクローズ
            self.form.destroy()                                     # フォームを閉じる
            self.DevId = None

    def SmplStart(self):
        """サンプリングを開始する"""
        self.CmbbConn['state'] = tk.DISABLED
        self.BtnStart['text'] = self.SMPL_BTN_STOP
        self.PauseT = False
        self.smpl_t.Start()                                         # タイマー開始

    def SmplStop(self):
        """サンプリングを停止する"""
        self.smpl_t.Stop()                                          # タイマー停止
        self.CmbbConn['state'] = tk.NORMAL
        self.BtnStart['text'] = self.SMPL_BTN_START
    
    # timer -------------------------------------
    def SampleT(self):
        """サンプルタイマー"""
        rData = 0.0
        tData = 0.0
        for cnt in range(100):
            ret = TUSBSPT.Tusbs01pt_Single_Sample(self.DevId,self.CmbbConn.current(),0) # 抵抗データの取得
            if ret[0] != 0:
                self.LbldVolt['text'] = "Error!"
                return
            rData += ret[1]
            ret = TUSBSPT.Tusbs01pt_Single_Sample(self.DevId,self.CmbbConn.current(),1)   # 温度データの取得
            if ret[0] != 0:
                self.LbldTemp['text'] = "Error!"
                return
            tData += ret[1]
        rData /= 100.0
        tData /= 100.0
        self.LbldVolt['text'] = format(rData,"5.1f")
        self.LbldTemp['text'] = format(tData,"5.1f")

    # ボタン等ウィジットの操作イベントハンドラ ----------------------
    def BtnStart_on(self):
        """開始、停止ボタンハンドラ"""
        if self.BtnStart["text"] == self.SMPL_BTN_START:    # 測定開始
            self.SmplStart()
        else:                                               # 測定停止
            self.SmplStop()
    
    # フォームとウィジェットを生成する処理---------------------------
    def formgen(self):
        self.form = tk.Tk()
        form = self.form
        form.geometry('328x215')
        form.title('TUSB-S01PT Sample Program (single)')

        self.ConnDict ={
            "2線式":0,
            "3線式":1,
            "4線式":2,
        }
        self.LbldVolt = GetLabelDisp(form,"",0.3,0.35,0.2)
        GetLabel(form,"Ohm",0.7,0.2)
        GetLabel(form,"As Pt100",0.15,0.5)
        self.LbldTemp = GetLabelDisp(form,"",0.3,0.35,0.5)
        GetLabel(form,"℃",0.7,0.5)
        self.BtnStart = GetButton(form,self.SMPL_BTN_START,self.BtnStart_on,0.25,0.5,0.8)
        self.CmbbConn = GetComboBox(form,list(self.ConnDict.keys()),0.2,0.75,0.8)

# 実行部 ---------------------------------
if __name__=="__main__":
    DevId = 0
    if( len(sys.argv) >= 2 ):
        if sys.argv[1].isdigit():
            DevId = int(sys.argv[1])    # コマンドライン引数でID設定
    tmp = Tusbs01pt_Device(DevId=DevId)
    tmp.form.mainloop()
